/*
 * Global function prototypes for Mathomatic.
 */

int		clear(), quit(), list_cmd(), simplify(), help(), eliminate();
int		unfactor(), compare_cmd(), extrema_cmd();
int		read_cmd(), flist_cmd(), calculate();
int		factor(), derivative(), replace();
int		save(), print_cmd(), taylor(), limit_cmd();
int		copy_cmd(), divide_cmd(), pause_cmd();
int		edit(), real(), imaginary(), tally();
int		roots_cmd(), set_cmd(), code_cmd(), optimize_cmd(), push_cmd();
int		sum_cmd(), product_cmd(), integrate_cmd(), nintegrate(), laplace_cmd();
char		*skip_space(), *skip_param();
char		*skip_num();
char		*getstring();
char		*parse_section(), *parse_var(), *parse_var2();
char		*list_exp(), *list_equation();
double		gcd(), my_round(), multiply_out_unique();
complexs	complex_mult(), complex_div(), complex_exp(), complex_pow(), complex_log();

void fphandler(int sig);
void inthandler(int sig);
void alarmhandler(int sig);
void resizehandler(int sig);
void exit_program(int exit_value);
